@@ -110,11 +110,11 @@ class EditProjectForm(forms.ModelForm):
 
     def clean_origins(self):
         value = self.cleaned_data.get('origins')
-        if value:
-            values = filter(bool, (v.strip() for v in value.split('\n')))
-            for value in values:
-                self._url_validator(value)
-        return values
+        if not value:
+            return value
+        values = filter(bool, (v.strip() for v in value.split('\n')))
+        for value in values:
+            self._url_validator(value)
 
 
 class EditProjectAdminForm(EditProjectForm):
