@@ -66,6 +66,11 @@ def manage_projects(request):
         order_by = '-date_added'
     elif sort == 'name':
         order_by = 'name'
+    elif sort == 'events':
+        project_list = project_list.annotate(
+            events=Sum('projectcountbyminute__times_seen'),
+        ).filter(projectcountbyminute__date__gte=datetime.datetime.now() - datetime.timedelta(days=30))
+        order_by = '-events'
 
     project_list = project_list.order_by(order_by)
 
